==> sylpheed-claws-gtk2_1.9.14.orig.tar.gz: sylpheed-claws-gtk2-1.9.14/src/quote_fmt_parse.h <==
/* A Bison parser, made by GNU Bison 2.0.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     SHOW_NEWSGROUPS = 258,
     SHOW_DATE = 259,
     SHOW_FROM = 260,
     SHOW_FULLNAME = 261,
     SHOW_FIRST_NAME = 262,
     SHOW_LAST_NAME = 263,
     SHOW_SENDER_INITIAL = 264,
     SHOW_SUBJECT = 265,
     SHOW_TO = 266,
     SHOW_MESSAGEID = 267,
     SHOW_PERCENT = 268,
     SHOW_CC = 269,
     SHOW_REFERENCES = 270,
     SHOW_MESSAGE = 271,
     SHOW_QUOTED_MESSAGE = 272,
     SHOW_BACKSLASH = 273,
     SHOW_TAB = 274,
     SHOW_QUOTED_MESSAGE_NO_SIGNATURE = 275,
     SHOW_MESSAGE_NO_SIGNATURE = 276,
     SHOW_EOL = 277,
     SHOW_QUESTION_MARK = 278,
     SHOW_PIPE = 279,
     SHOW_OPARENT = 280,
     SHOW_CPARENT = 281,
     QUERY_DATE = 282,
     QUERY_FROM = 283,
     QUERY_FULLNAME = 284,
     QUERY_SUBJECT = 285,
     QUERY_TO = 286,
     QUERY_NEWSGROUPS = 287,
     QUERY_MESSAGEID = 288,
     QUERY_CC = 289,
     QUERY_REFERENCES = 290,
     INSERT_FILE = 291,
     INSERT_PROGRAMOUTPUT = 292,
     OPARENT = 293,
     CPARENT = 294,
     CHARACTER = 295,
     SHOW_DATE_EXPR = 296,
     SET_CURSOR_POS = 297
   };
#endif
#define SHOW_NEWSGROUPS 258
#define SHOW_DATE 259
#define SHOW_FROM 260
#define SHOW_FULLNAME 261
#define SHOW_FIRST_NAME 262
#define SHOW_LAST_NAME 263
#define SHOW_SENDER_INITIAL 264
#define SHOW_SUBJECT 265
#define SHOW_TO 266
#define SHOW_MESSAGEID 267
#define SHOW_PERCENT 268
#define SHOW_CC 269
#define SHOW_REFERENCES 270
#define SHOW_MESSAGE 271
#define SHOW_QUOTED_MESSAGE 272
#define SHOW_BACKSLASH 273
#define SHOW_TAB 274
#define SHOW_QUOTED_MESSAGE_NO_SIGNATURE 275
#define SHOW_MESSAGE_NO_SIGNATURE 276
#define SHOW_EOL 277
#define SHOW_QUESTION_MARK 278
#define SHOW_PIPE 279
#define SHOW_OPARENT 280
#define SHOW_CPARENT 281
#define QUERY_DATE 282
#define QUERY_FROM 283
#define QUERY_FULLNAME 284
#define QUERY_SUBJECT 285
#define QUERY_TO 286
#define QUERY_NEWSGROUPS 287
#define QUERY_MESSAGEID 288
#define QUERY_CC 289
#define QUERY_REFERENCES 290
#define INSERT_FILE 291
#define INSERT_PROGRAMOUTPUT 292
#define OPARENT 293
#define CPARENT 294
#define CHARACTER 295
#define SHOW_DATE_EXPR 296
#define SET_CURSOR_POS 297




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 388 "quote_fmt_parse.y"
typedef union YYSTYPE {
	char chr;
	char str[256];
} YYSTYPE;
/* Line 1318 of yacc.c.  */
#line 126 "quote_fmt_parse.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> sylpheed-claws-gtk2_2.1.1.orig.tar.gz: sylpheed-claws-gtk2-2.1.1/src/quote_fmt_parse.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     SHOW_NEWSGROUPS = 258,
     SHOW_DATE = 259,
     SHOW_FROM = 260,
     SHOW_FULLNAME = 261,
     SHOW_FIRST_NAME = 262,
     SHOW_LAST_NAME = 263,
     SHOW_SENDER_INITIAL = 264,
     SHOW_SUBJECT = 265,
     SHOW_TO = 266,
     SHOW_MESSAGEID = 267,
     SHOW_PERCENT = 268,
     SHOW_CC = 269,
     SHOW_REFERENCES = 270,
     SHOW_MESSAGE = 271,
     SHOW_QUOTED_MESSAGE = 272,
     SHOW_BACKSLASH = 273,
     SHOW_TAB = 274,
     SHOW_QUOTED_MESSAGE_NO_SIGNATURE = 275,
     SHOW_MESSAGE_NO_SIGNATURE = 276,
     SHOW_EOL = 277,
     SHOW_QUESTION_MARK = 278,
     SHOW_PIPE = 279,
     SHOW_OPARENT = 280,
     SHOW_CPARENT = 281,
     QUERY_DATE = 282,
     QUERY_FROM = 283,
     QUERY_FULLNAME = 284,
     QUERY_SUBJECT = 285,
     QUERY_TO = 286,
     QUERY_NEWSGROUPS = 287,
     QUERY_MESSAGEID = 288,
     QUERY_CC = 289,
     QUERY_REFERENCES = 290,
     INSERT_FILE = 291,
     INSERT_PROGRAMOUTPUT = 292,
     OPARENT = 293,
     CPARENT = 294,
     CHARACTER = 295,
     SHOW_DATE_EXPR = 296,
     SET_CURSOR_POS = 297
   };
#endif
/* Tokens.  */
#define SHOW_NEWSGROUPS 258
#define SHOW_DATE 259
#define SHOW_FROM 260
#define SHOW_FULLNAME 261
#define SHOW_FIRST_NAME 262
#define SHOW_LAST_NAME 263
#define SHOW_SENDER_INITIAL 264
#define SHOW_SUBJECT 265
#define SHOW_TO 266
#define SHOW_MESSAGEID 267
#define SHOW_PERCENT 268
#define SHOW_CC 269
#define SHOW_REFERENCES 270
#define SHOW_MESSAGE 271
#define SHOW_QUOTED_MESSAGE 272
#define SHOW_BACKSLASH 273
#define SHOW_TAB 274
#define SHOW_QUOTED_MESSAGE_NO_SIGNATURE 275
#define SHOW_MESSAGE_NO_SIGNATURE 276
#define SHOW_EOL 277
#define SHOW_QUESTION_MARK 278
#define SHOW_PIPE 279
#define SHOW_OPARENT 280
#define SHOW_CPARENT 281
#define QUERY_DATE 282
#define QUERY_FROM 283
#define QUERY_FULLNAME 284
#define QUERY_SUBJECT 285
#define QUERY_TO 286
#define QUERY_NEWSGROUPS 287
#define QUERY_MESSAGEID 288
#define QUERY_CC 289
#define QUERY_REFERENCES 290
#define INSERT_FILE 291
#define INSERT_PROGRAMOUTPUT 292
#define OPARENT 293
#define CPARENT 294
#define CHARACTER 295
#define SHOW_DATE_EXPR 296
#define SET_CURSOR_POS 297




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 408 "quote_fmt_parse.y"
typedef union YYSTYPE {
	char chr;
	char str[256];
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 127 "quote_fmt_parse.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
